#
# pydar.py
#
# Python Digital Audio Recorder
#
# Copyright (C) 2003 Daniel Thompson <d.thompson@gmx.net> 
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#

import getopt, os, sys
from pydar import tuner

def usage():
	print """Usage: pydar.py [OPTIONS]

Options:
  -h, --help	  Display this information
  -m, --mute	  Mute the radio device
  -t, --tune=<ch> Tune the radio device to <ch>

Report bugs to pydar@redfelineninja.org.uk.
"""

def main(
	scriptFile = sys.prefix + '/bin/pydar',
	gladeFile = sys.prefix + '/share/pydar/glade/pydar.glade',
	stateFile = None
):
	try:
		opts, args = getopt.getopt(sys.argv[1:], 'hmt:', ['help', 'mute', 'tune='])
	except getopt.GetoptError:
		usage()
		sys.exit(2)
	mute = False
	tune = None
	for o, a in opts:
		if o in ('-h', '--help'):
			usage()
			sys.exit()
		if o in ('-m', '--mute'):
			mute = True
		if o in ('-t', '--tune'):
			tune = a

	# create the tuner object
	t = tuner.Tuner(scriptFile)

	if True == mute:
		t.mute()
		sys.exit()
	
	if None != tune:
		t.tune(tune)
		sys.exit()

	# determine what to use as a home directory
	if stateFile == None:
		if os.environ.has_key('HOME'):
			stateFile = os.environ['HOME'] + '/.pydar'
		elif os.name == 'posix':
			stateFile = os.path.expanduser('~/.pydar')
		else:
			print "WARNING: cannot determine home directory"
			stateFile = 'pydar.statefile'

	# we can't import pygtk (or the gui) until this point since that
	# would prevent us working from at jobs. 
	import pygtk
	pygtk.require('2.0')
	import pydar.gui, gtk

	# open the main window and start handling events
	ui = pydar.gui.PydarGui(gladeFile, stateFile, t)
	gtk.mainloop()

if __name__ == "__main__":
	main()
